@@ -6,7 +6,7 @@ from requests import request
 
 from moloni import __version__
 from moloni.base.config import MoloniBaseUrl
-from moloni.base.helpers import AccessTokenResponse, ApiResponse, ApiException
+from moloni.base.helpers import AccessTokenResponse, ApiResponse, ApiResponseValidator
 from .logger_config import setup_logger
 
 logger = setup_logger(__name__)
@@ -124,7 +124,7 @@ class MoloniBaseClient:
         )
         logger.setLevel(log_level)
 
-    def flatten_dict(self, data, parent_key='', sep='[', end_sep=']'):
+    def flatten_dict(self, data, parent_key="", sep="[", end_sep="]"):
         items = []
         if isinstance(data, dict):
             for k, v in data.items():
@@ -139,7 +139,10 @@ class MoloniBaseClient:
         return dict(items)
 
     def create_form_data(self, data):
-        return {k: str(v) if v is not None else '' for k, v in self.flatten_dict(data).items()}
+        return {
+            k: str(v) if v is not None else ""
+            for k, v in self.flatten_dict(data).items()
+        }
 
     def _request(self, path, data=None, **kwargs) -> ApiResponse:
         data = data or {}
@@ -157,6 +160,4 @@ class MoloniBaseClient:
         logger.debug(res.request.url)
         logger.debug(res.content)
 
-        if 200 <= res.status_code < 300:
-            return ApiResponse(res, data)
-        raise ApiException(res, data)
+        return ApiResponseValidator(res, data).validate()
